@@ -169,7 +169,7 @@ public class CityLevel extends RegularLevel {
 									if (b instanceof Wand.Charger
 											|| b instanceof Artifact.ArtifactBuff
 											|| b instanceof Ring.RingBuff
-											|| b instanceof MeleeWeapon.Charger
+											//not melee charger, Duelist should retain her charge count
 											|| b instanceof ClassArmor.Charger){
 										b.detach();
 									}
