@@ -393,6 +393,10 @@ public class InventoryPane extends Component {
 		updateInventory();
 	}
 
+	public WndBag.ItemSelector getSelector() {
+		return selector;
+	}
+
 	public boolean isSelecting(){
 		return selector != null;
 	}
